@@ -20,25 +20,27 @@ import sys
 import platform
 import itertools
 import distutils.errors
-from pkg_resources.extern.packaging.version import LegacyVersion
+from packaging.version import LegacyVersion
 
-from setuptools.extern.six.moves import filterfalse
+from six.moves import filterfalse
 
 from .monkey import get_unpatched
 
 if platform.system() == 'Windows':
-    from setuptools.extern.six.moves import winreg
+    from six.moves import winreg
     safe_env = os.environ
 else:
     """
     Mock winreg and environ so the module can be imported
     on this platform.
     """
+
     class winreg:
         HKEY_USERS = None
         HKEY_CURRENT_USER = None
         HKEY_LOCAL_MACHINE = None
         HKEY_CLASSES_ROOT = None
+
     safe_env = dict()
 
 try:
@@ -270,7 +272,7 @@ class PlatformInfo:
         )
 
     def target_dir(self, hidex86=False, x64=False):
-        """
+        r"""
         Target platform specific subfolder.
 
         Parameters
@@ -292,7 +294,7 @@ class PlatformInfo:
         )
 
     def cross_dir(self, forcex86=False):
-        """
+        r"""
         Cross platform specific subfolder.
 
         Parameters
@@ -458,6 +460,7 @@ class SystemInfo:
     vc_ver: float
         Required Microsoft Visual C++ version.
     """
+
     # Variables and properties in this class use originals CamelCase variables
     # names from Microsoft source files for more easy comparaison.
     WinDir = safe_env.get('WinDir', '')
@@ -758,6 +761,7 @@ class EnvironmentInfo:
     vc_min_ver: float
         Minimum Microsoft Visual C++ version.
     """
+
     # Variables and properties in this class use originals CamelCase variables
     # names from Microsoft source files for more easy comparaison.
 
